########################################################
Notices about content attributions of third-party assets
########################################################

The copyright and trademarks of particular images, pictograms and brand names
are held by their respective owners, unless otherwise noted.

- Combustion engine innards from Daimler AG Archive
- depa.tech/DEPAROM icon from `Moving Targets Consulting GmbH <MTC_>`_

.. _MTC: https://mtc.berlin/
